@@ -14,15 +14,9 @@ from PySDNSim.NetworkService import NetworkService
 
 class Backend:
     _ready: Union[bool, None]
-    _terminated: Union[bool, None]
-    _max_num_threads: int
-    _main_thread: Thread
-    _terminator: Thread
-    _backend_thread_queue: List[Thread]
-    _running_backend_threads: List[Thread]
     _debug:bool
 
-    def __init__(self, max_num_threads: int = 4, debug: bool = False):
+    def __init__(self, debug: bool = False):
         self._debug = debug
         if os.path.isfile("backend.jar"):
             if self.debug:
@@ -32,38 +26,17 @@ class Backend:
             if self.debug:
                 logger.error("Can not find simulation backend executable file.")
             self._ready = False
-        self._terminated = False
-        self._max_num_threads = max_num_threads
-        self._backend_thread_queue = list()
-        self._running_backend_threads = list()
+
+
 
     @property
     def ready(self):
         return self._ready
 
-    @property
-    def terminated(self):
-        return self._terminated
-
-    @property
-    def max_num_threads(self):
-        return self._max_num_threads
-
     @property
     def main_thread(self):
         return self._main_thread
 
-    @property
-    def termminator(self):
-        return self._terminator
-
-    @property
-    def backend_thread_queue(self):
-        return self._backend_thread_queue
-
-    @property
-    def running_backend_threads(self):
-        return self._running_backend_threads
     
     @property
     def debug(self):
@@ -139,83 +112,36 @@ class Backend:
             os.makedirs("configs")
         
         logger.info(f"Generated new simulation configuration file\t {config_file}.")
-        with open("configs/" + config_file, "w+") as config_file:
-            json.dump(sim_config, config_file, indent=4)
+        with open("configs/" + config_file, "w+") as file:
+            json.dump(sim_config, file, indent=4)
 
-    def start(self):
+    def run_experiment(self, experiment: Experiment, output_path: str):
         if self.ready is True:
-            self._main_thread = Thread(target=self.execute_experiments)
-            self._main_thread.start()
-        else:
-            raise RuntimeError("Can't start, simulation backend executable file is missing.")
+                config_file = experiment.name + ".json"
+                
+                if os.path.exists(output_path) is False:
+                    os.makedirs(output_path)
 
-    def stop(self):
-        if self.main_thread.is_alive():
-            
-            def wait_for_running_process():
-                while len(self.running_backend_threads) > 0 or len(self.backend_thread_queue) > 0:
-                    pass
-                self._terminated = True
-
-            self._terminator = Thread(target=wait_for_running_process, name="terminator")
-            self._terminator.start()
-            self._terminator.join()
-        else:
-            raise RuntimeWarning(f"Simulation backend has not started yet.")
-
-    def add_experiment(self, experiment: Experiment, output_path: str):
-        if self.ready is True:
-            config_file = experiment.name + ".json"
-            
-            if os.path.exists(output_path) is False:
-                os.makedirs(output_path)
-
-            def backend_target():
-                """
-                Call javar simulation backend with configuration file.
-
-                :return: None
-                """
-                subprocess.call(
-                    [
-                        "java",
-                        "-jar",
-                        "backend.jar",
-                        "./configs/" + config_file,
-                        output_path + "/" + experiment.name,
-                    ]
+                self.generate_config(
+                    config=experiment.config,
+                    hosts=[experiment.host],
+                    microservices=experiment.microservices,
+                    network_services=experiment.network_services,
+                    config_file=config_file,
                 )
 
-            self.generate_config(
-                config=experiment.config,
-                hosts=[experiment.host],
-                microservices=experiment.microservices,
-                network_services=experiment.network_services,
-                config_file=config_file,
-            )
+                subprocess.call(
+                        [
+                            "java",
+                            "-jar",
+                            "backend.jar",
+                            "./configs/" + config_file,
+                            output_path + "/" + experiment.name,
+                        ]
+                    )
+                logger.info(f"Simulation completed for experiment\t {experiment.name}.")
 
-            backend_process = Thread(target=backend_target, name=experiment.name)
-            self.backend_thread_queue.append(backend_process)
         else:
             raise RuntimeError("Simulation backend executable file is missing.")
 
-    def execute_experiments(self):
-        while self.terminated is False or len(self.running_backend_threads)>0:
-            if len(self.running_backend_threads) != 0:
-                for backend_thread in self.running_backend_threads[:]:
-                    if backend_thread.is_alive():
-                        continue
-                    else:
-                        self._running_backend_threads.remove(backend_thread)
-                        logger.info(f"Experiment\t {backend_thread.name} \tfinsihed.")
-
-            while (
-                len(self.running_backend_threads) < self.max_num_threads
-                and len(self.backend_thread_queue) != 0
-                and self.terminated != True
-            ):
-                backend_thread = self.backend_thread_queue.pop(0)
-                self._running_backend_threads.append(backend_thread)
-                backend_thread.start()
-                logger.info(f"Experiment\t {backend_thread.name} \tstarted.")
-        logger.info("Simulation terminated, all experiment complete successfully.")
+        
